@@ -1,7 +1,7 @@
 from typing import Optional
 
 import pytest
-from dirty_equals import HasRepr, IsDict, IsOneOf
+from dirty_equals import HasRepr
 from fastapi import Depends, FastAPI
 from fastapi.exceptions import ResponseValidationError
 from fastapi.testclient import TestClient
@@ -63,23 +63,13 @@ def test_validator_is_cloned(client: TestClient):
     with pytest.raises(ResponseValidationError) as err:
         client.get("/model/modelX")
     assert err.value.errors() == [
-        IsDict(
-            {
-                "type": "value_error",
-                "loc": ("response", "name"),
-                "msg": "Value error, name must end in A",
-                "input": "modelX",
-                "ctx": {"error": HasRepr("ValueError('name must end in A')")},
-            }
-        )
-        | IsDict(
-            # TODO remove when deprecating Pydantic v1
-            {
-                "loc": ("response", "name"),
-                "msg": "name must end in A",
-                "type": "value_error",
-            }
-        )
+        {
+            "type": "value_error",
+            "loc": ("response", "name"),
+            "msg": "Value error, name must end in A",
+            "input": "modelX",
+            "ctx": {"error": HasRepr("ValueError('name must end in A')")},
+        }
     ]
 
 
@@ -145,23 +135,14 @@ def test_openapi_schema(client: TestClient):
                     },
                     "ModelA": {
                         "title": "ModelA",
-                        "required": IsOneOf(
-                            ["name", "description", "foo"],
-                            # TODO remove when deprecating Pydantic v1
-                            ["name", "foo"],
-                        ),
+                        "required": ["name", "foo"],
                         "type": "object",
                         "properties": {
                             "name": {"title": "Name", "type": "string"},
-                            "description": IsDict(
-                                {
-                                    "title": "Description",
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                }
-                            )
-                            |
-                            # TODO remove when deprecating Pydantic v1
-                            IsDict({"title": "Description", "type": "string"}),
+                            "description": {
+                                "title": "Description",
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                            },
                             "foo": {"$ref": "#/components/schemas/ModelB"},
                             "tags": {
                                 "additionalProperties": {"type": "string"},
@@ -184,6 +165,8 @@ def test_openapi_schema(client: TestClient):
                         "required": ["loc", "msg", "type"],
                         "type": "object",
                         "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
                             "loc": {
                                 "title": "Location",
                                 "type": "array",
