@@ -3,6 +3,7 @@ from typing import Annotated, Optional
 import pytest
 from fastapi import Cookie, FastAPI
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 from pydantic import BaseModel, Field
 
 app = FastAPI()
@@ -30,17 +31,19 @@ async def read_model_optional_str(p: Annotated[CookieModelOptionalStr, Cookie()]
     ["/optional-str", "/model-optional-str"],
 )
 def test_optional_str_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [{"type": "string"}, {"type": "null"}],
-                "title": "P",
-            },
-            "name": "p",
-            "in": "cookie",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                    "title": "P",
+                },
+                "name": "p",
+                "in": "cookie",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -91,17 +94,19 @@ async def read_model_optional_alias(p: Annotated[CookieModelOptionalAlias, Cooki
     ["/optional-alias", "/model-optional-alias"],
 )
 def test_optional_str_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [{"type": "string"}, {"type": "null"}],
-                "title": "P Alias",
-            },
-            "name": "p_alias",
-            "in": "cookie",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                    "title": "P Alias",
+                },
+                "name": "p_alias",
+                "in": "cookie",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -169,17 +174,19 @@ def read_model_optional_validation_alias(
     ["/optional-validation-alias", "/model-optional-validation-alias"],
 )
 def test_optional_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [{"type": "string"}, {"type": "null"}],
-                "title": "P Val Alias",
-            },
-            "name": "p_val_alias",
-            "in": "cookie",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                    "title": "P Val Alias",
+                },
+                "name": "p_val_alias",
+                "in": "cookie",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
@@ -255,17 +262,19 @@ def read_model_optional_alias_and_validation_alias(
     ],
 )
 def test_optional_alias_and_validation_alias_schema(path: str):
-    assert app.openapi()["paths"][path]["get"]["parameters"] == [
-        {
-            "required": False,
-            "schema": {
-                "anyOf": [{"type": "string"}, {"type": "null"}],
-                "title": "P Val Alias",
-            },
-            "name": "p_val_alias",
-            "in": "cookie",
-        }
-    ]
+    assert app.openapi()["paths"][path]["get"]["parameters"] == snapshot(
+        [
+            {
+                "required": False,
+                "schema": {
+                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                    "title": "P Val Alias",
+                },
+                "name": "p_val_alias",
+                "in": "cookie",
+            }
+        ]
+    )
 
 
 @pytest.mark.parametrize(
