@@ -1,7 +1,6 @@
 import importlib
 
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 from inline_snapshot import snapshot
 
@@ -60,33 +59,23 @@ def test_header_param_model_no_underscore(client: TestClient):
     assert response.json() == snapshot(
         {
             "detail": [
-                IsDict(
-                    {
-                        "type": "missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "Field required",
-                        "input": {
-                            "host": "testserver",
-                            "traceparent": "123",
-                            "x_tag": [],
-                            "accept": "*/*",
-                            "accept-encoding": "gzip, deflate",
-                            "connection": "keep-alive",
-                            "user-agent": "testclient",
-                            "save-data": "true",
-                            "if-modified-since": "yesterday",
-                            "x-tag": ["one", "two"],
-                        },
-                    }
-                )
-                | IsDict(
-                    # TODO: remove when deprecating Pydantic v1
-                    {
-                        "type": "value_error.missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "field required",
-                    }
-                )
+                {
+                    "type": "missing",
+                    "loc": ["header", "save_data"],
+                    "msg": "Field required",
+                    "input": {
+                        "host": "testserver",
+                        "traceparent": "123",
+                        "x_tag": [],
+                        "accept": "*/*",
+                        "accept-encoding": "gzip, deflate",
+                        "connection": "keep-alive",
+                        "user-agent": "testclient",
+                        "save-data": "true",
+                        "if-modified-since": "yesterday",
+                        "x-tag": ["one", "two"],
+                    },
+                }
             ]
         }
     )
@@ -110,29 +99,19 @@ def test_header_param_model_invalid(client: TestClient):
     assert response.json() == snapshot(
         {
             "detail": [
-                IsDict(
-                    {
-                        "type": "missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "Field required",
-                        "input": {
-                            "x_tag": [],
-                            "host": "testserver",
-                            "accept": "*/*",
-                            "accept-encoding": "gzip, deflate",
-                            "connection": "keep-alive",
-                            "user-agent": "testclient",
-                        },
-                    }
-                )
-                | IsDict(
-                    # TODO: remove when deprecating Pydantic v1
-                    {
-                        "type": "value_error.missing",
-                        "loc": ["header", "save_data"],
-                        "msg": "field required",
-                    }
-                )
+                {
+                    "type": "missing",
+                    "loc": ["header", "save_data"],
+                    "msg": "Field required",
+                    "input": {
+                        "x_tag": [],
+                        "host": "testserver",
+                        "accept": "*/*",
+                        "accept-encoding": "gzip, deflate",
+                        "connection": "keep-alive",
+                        "user-agent": "testclient",
+                    },
+                }
             ]
         }
     )
@@ -183,37 +162,19 @@ def test_openapi_schema(client: TestClient):
                                 "name": "if_modified_since",
                                 "in": "header",
                                 "required": False,
-                                "schema": IsDict(
-                                    {
-                                        "anyOf": [{"type": "string"}, {"type": "null"}],
-                                        "title": "If Modified Since",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "type": "string",
-                                        "title": "If Modified Since",
-                                    }
-                                ),
+                                "schema": {
+                                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                                    "title": "If Modified Since",
+                                },
                             },
                             {
                                 "name": "traceparent",
                                 "in": "header",
                                 "required": False,
-                                "schema": IsDict(
-                                    {
-                                        "anyOf": [{"type": "string"}, {"type": "null"}],
-                                        "title": "Traceparent",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "type": "string",
-                                        "title": "Traceparent",
-                                    }
-                                ),
+                                "schema": {
+                                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                                    "title": "Traceparent",
+                                },
                             },
                             {
                                 "name": "x_tag",
@@ -263,6 +224,8 @@ def test_openapi_schema(client: TestClient):
                     },
                     "ValidationError": {
                         "properties": {
+                            "ctx": {"title": "Context", "type": "object"},
+                            "input": {"title": "Input"},
                             "loc": {
                                 "items": {
                                     "anyOf": [{"type": "string"}, {"type": "integer"}]
